pub struct StorageBatchOperations { /* private fields */ }Expand description
Implements a client for the Storage Batch Operations API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = StorageBatchOperations::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_jobs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Storage Batch Operations offers a managed experience to perform batch operations on millions of Cloud Storage objects in a serverless fashion. With this service, you can automate and simplify large scale API operations performed on Cloud Storage objects.
Configuration
To configure StorageBatchOperations use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://storagebatchoperations.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
StorageBatchOperations holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap StorageBatchOperations in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl StorageBatchOperations
impl StorageBatchOperations
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for StorageBatchOperations.
let client = StorageBatchOperations::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: StorageBatchOperations + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: StorageBatchOperations + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_jobs(&self) -> ListJobs
pub fn list_jobs(&self) -> ListJobs
Lists Jobs in a given project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations, parent: &str
) -> Result<()> {
let mut list = client.list_jobs()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_job(&self) -> GetJob
pub fn get_job(&self) -> GetJob
Gets a batch job.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations, name: &str
) -> Result<()> {
let response = client.get_job()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_job(&self) -> CreateJob
pub fn create_job(&self) -> CreateJob
Creates a batch job.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_storagebatchoperations_v1::model::Job;
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations, parent: &str
) -> Result<()> {
let response = client.create_job()
.set_parent(parent)
.set_job_id("job_id_value")
.set_job(
Job::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_job(&self) -> DeleteJob
pub fn delete_job(&self) -> DeleteJob
Deletes a batch job.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations, name: &str
) -> Result<()> {
client.delete_job()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn cancel_job(&self) -> CancelJob
pub fn cancel_job(&self) -> CancelJob
Cancels a batch job.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
let response = client.cancel_job()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_bucket_operations(&self) -> ListBucketOperations
pub fn list_bucket_operations(&self) -> ListBucketOperations
Lists BucketOperations in a given project and job.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations, parent: &str
) -> Result<()> {
let mut list = client.list_bucket_operations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_bucket_operation(&self) -> GetBucketOperation
pub fn get_bucket_operation(&self) -> GetBucketOperation
Gets a BucketOperation.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations, name: &str
) -> Result<()> {
let response = client.get_bucket_operation()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_storagebatchoperations_v1::Result;
async fn sample(
client: &StorageBatchOperations
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for StorageBatchOperations
impl Clone for StorageBatchOperations
Sourcefn clone(&self) -> StorageBatchOperations
fn clone(&self) -> StorageBatchOperations
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more