Module model

The messages and enums that are part of this client library.

Modules

bucket_list
Defines additional types related to BucketList.
bucket_operation
Defines additional types related to BucketOperation.
job
Defines additional types related to Job.
logging_config
Defines additional types related to LoggingConfig.
object_retention
Defines additional types related to ObjectRetention.
put_object_hold
Defines additional types related to PutObjectHold.
update_object_custom_context
Defines additional types related to UpdateObjectCustomContext.

Structs

BucketList
Describes list of buckets and their objects to be transformed.
BucketOperation
BucketOperation represents a bucket-level breakdown of a Job.
CancelJobRequest
Message for Job to Cancel
CancelJobResponse
Message for response to cancel Job.
Counters
Describes details about the progress of the job.
CreateJobRequest
Message for creating a Job
CustomContextUpdates
Describes a collection of updates to apply to custom contexts identified by key.
DeleteJobRequest
Message for deleting a Job
DeleteObject
Describes options to delete an object.
ErrorLogEntry
An entry describing an error that has occurred.
ErrorSummary
A summary of errors by error code, plus a count and sample error log entries.
GetBucketOperationRequest
Message for getting a BucketOperation.
GetJobRequest
Message for getting a Job
Job
The Storage Batch Operations Job description.
ListBucketOperationsRequest
Message for request to list BucketOperations
ListBucketOperationsResponse
Message for response to listing BucketOperations
ListJobsRequest
Message for request to list Jobs
ListJobsResponse
Message for response to listing Jobs
LoggingConfig
Specifies the Cloud Logging behavior.
Manifest
Describes list of objects to be transformed.
ObjectCustomContextPayload
Describes the payload of a user defined object custom context.
ObjectRetention
Describes options for object retention update.
OperationMetadata
Represents the metadata of the long-running operation.
PrefixList
Describes prefixes of objects to be transformed.
PutMetadata
Describes options for object metadata update.
PutObjectHold
Describes options to update object hold.
RewriteObject
Describes options for object rewrite.
UpdateObjectCustomContext
Describes options to update object custom contexts.