#[non_exhaustive]pub struct BucketOperation {
pub name: String,
pub bucket_name: String,
pub create_time: Option<Timestamp>,
pub start_time: Option<Timestamp>,
pub complete_time: Option<Timestamp>,
pub counters: Option<Counters>,
pub error_summaries: Vec<ErrorSummary>,
pub state: State,
pub object_configuration: Option<ObjectConfiguration>,
pub transformation: Option<Transformation>,
/* private fields */
}Expand description
BucketOperation represents a bucket-level breakdown of a Job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the BucketOperation. This is defined by the service. Format: projects/{project}/locations/global/jobs/{job_id}/bucketOperations/{bucket_operation}.
bucket_name: StringThe bucket name of the objects to be transformed in the BucketOperation.
create_time: Option<Timestamp>Output only. The time that the BucketOperation was created.
start_time: Option<Timestamp>Output only. The time that the BucketOperation was started.
complete_time: Option<Timestamp>Output only. The time that the BucketOperation was completed.
counters: Option<Counters>Output only. Information about the progress of the bucket operation.
error_summaries: Vec<ErrorSummary>Output only. Summarizes errors encountered with sample error log entries.
state: StateOutput only. State of the BucketOperation.
object_configuration: Option<ObjectConfiguration>Specifies objects to be transformed in the BucketOperation.
transformation: Option<Transformation>Action to be performed on the objects.
Implementations
Sourceimpl BucketOperation
impl BucketOperation
Sourcepub fn set_bucket_name<T: Into<String>>(self, v: T) -> Self
pub fn set_bucket_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = BucketOperation::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = BucketOperation::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = BucketOperation::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = BucketOperation::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = BucketOperation::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = BucketOperation::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_complete_time<T>(self, v: T) -> Self
pub fn set_complete_time<T>(self, v: T) -> Self
Sets the value of complete_time.
Example
use wkt::Timestamp;
let x = BucketOperation::new().set_complete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_complete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_complete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of complete_time.
Example
use wkt::Timestamp;
let x = BucketOperation::new().set_or_clear_complete_time(Some(Timestamp::default()/* use setters */));
let x = BucketOperation::new().set_or_clear_complete_time(None::<Timestamp>);Sourcepub fn set_counters<T>(self, v: T) -> Self
pub fn set_counters<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_counters<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_counters<T>(self, v: Option<T>) -> Self
Sourcepub fn set_error_summaries<T, V>(self, v: T) -> Self
pub fn set_error_summaries<T, V>(self, v: T) -> Self
Sets the value of error_summaries.
Example
use google_cloud_storagebatchoperations_v1::model::ErrorSummary;
let x = BucketOperation::new()
.set_error_summaries([
ErrorSummary::default()/* use setters */,
ErrorSummary::default()/* use (different) setters */,
]);Sourcepub fn set_object_configuration<T: Into<Option<ObjectConfiguration>>>(
self,
v: T,
) -> Self
pub fn set_object_configuration<T: Into<Option<ObjectConfiguration>>>( self, v: T, ) -> Self
Sets the value of object_configuration.
Note that all the setters affecting object_configuration are mutually
exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PrefixList;
let x = BucketOperation::new().set_object_configuration(Some(
google_cloud_storagebatchoperations_v1::model::bucket_operation::ObjectConfiguration::PrefixList(PrefixList::default().into())));Sourcepub fn prefix_list(&self) -> Option<&Box<PrefixList>>
pub fn prefix_list(&self) -> Option<&Box<PrefixList>>
The value of object_configuration
if it holds a PrefixList, None if the field is not set or
holds a different branch.
Sourcepub fn set_prefix_list<T: Into<Box<PrefixList>>>(self, v: T) -> Self
pub fn set_prefix_list<T: Into<Box<PrefixList>>>(self, v: T) -> Self
Sets the value of object_configuration
to hold a PrefixList.
Note that all the setters affecting object_configuration are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PrefixList;
let x = BucketOperation::new().set_prefix_list(PrefixList::default()/* use setters */);
assert!(x.prefix_list().is_some());
assert!(x.manifest().is_none());Sourcepub fn manifest(&self) -> Option<&Box<Manifest>>
pub fn manifest(&self) -> Option<&Box<Manifest>>
The value of object_configuration
if it holds a Manifest, None if the field is not set or
holds a different branch.
Sourcepub fn set_manifest<T: Into<Box<Manifest>>>(self, v: T) -> Self
pub fn set_manifest<T: Into<Box<Manifest>>>(self, v: T) -> Self
Sets the value of object_configuration
to hold a Manifest.
Note that all the setters affecting object_configuration are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::Manifest;
let x = BucketOperation::new().set_manifest(Manifest::default()/* use setters */);
assert!(x.manifest().is_some());
assert!(x.prefix_list().is_none());Sourcepub fn set_transformation<T: Into<Option<Transformation>>>(self, v: T) -> Self
pub fn set_transformation<T: Into<Option<Transformation>>>(self, v: T) -> Self
Sets the value of transformation.
Note that all the setters affecting transformation are mutually
exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PutObjectHold;
let x = BucketOperation::new().set_transformation(Some(
google_cloud_storagebatchoperations_v1::model::bucket_operation::Transformation::PutObjectHold(PutObjectHold::default().into())));Sourcepub fn put_object_hold(&self) -> Option<&Box<PutObjectHold>>
pub fn put_object_hold(&self) -> Option<&Box<PutObjectHold>>
The value of transformation
if it holds a PutObjectHold, None if the field is not set or
holds a different branch.
Sourcepub fn set_put_object_hold<T: Into<Box<PutObjectHold>>>(self, v: T) -> Self
pub fn set_put_object_hold<T: Into<Box<PutObjectHold>>>(self, v: T) -> Self
Sets the value of transformation
to hold a PutObjectHold.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PutObjectHold;
let x = BucketOperation::new().set_put_object_hold(PutObjectHold::default()/* use setters */);
assert!(x.put_object_hold().is_some());
assert!(x.delete_object().is_none());
assert!(x.put_metadata().is_none());
assert!(x.rewrite_object().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn delete_object(&self) -> Option<&Box<DeleteObject>>
pub fn delete_object(&self) -> Option<&Box<DeleteObject>>
The value of transformation
if it holds a DeleteObject, None if the field is not set or
holds a different branch.
Sourcepub fn set_delete_object<T: Into<Box<DeleteObject>>>(self, v: T) -> Self
pub fn set_delete_object<T: Into<Box<DeleteObject>>>(self, v: T) -> Self
Sets the value of transformation
to hold a DeleteObject.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::DeleteObject;
let x = BucketOperation::new().set_delete_object(DeleteObject::default()/* use setters */);
assert!(x.delete_object().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.put_metadata().is_none());
assert!(x.rewrite_object().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn put_metadata(&self) -> Option<&Box<PutMetadata>>
pub fn put_metadata(&self) -> Option<&Box<PutMetadata>>
The value of transformation
if it holds a PutMetadata, None if the field is not set or
holds a different branch.
Sourcepub fn set_put_metadata<T: Into<Box<PutMetadata>>>(self, v: T) -> Self
pub fn set_put_metadata<T: Into<Box<PutMetadata>>>(self, v: T) -> Self
Sets the value of transformation
to hold a PutMetadata.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PutMetadata;
let x = BucketOperation::new().set_put_metadata(PutMetadata::default()/* use setters */);
assert!(x.put_metadata().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.delete_object().is_none());
assert!(x.rewrite_object().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn rewrite_object(&self) -> Option<&Box<RewriteObject>>
pub fn rewrite_object(&self) -> Option<&Box<RewriteObject>>
The value of transformation
if it holds a RewriteObject, None if the field is not set or
holds a different branch.
Sourcepub fn set_rewrite_object<T: Into<Box<RewriteObject>>>(self, v: T) -> Self
pub fn set_rewrite_object<T: Into<Box<RewriteObject>>>(self, v: T) -> Self
Sets the value of transformation
to hold a RewriteObject.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::RewriteObject;
let x = BucketOperation::new().set_rewrite_object(RewriteObject::default()/* use setters */);
assert!(x.rewrite_object().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.delete_object().is_none());
assert!(x.put_metadata().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn update_object_custom_context(
&self,
) -> Option<&Box<UpdateObjectCustomContext>>
pub fn update_object_custom_context( &self, ) -> Option<&Box<UpdateObjectCustomContext>>
The value of transformation
if it holds a UpdateObjectCustomContext, None if the field is not set or
holds a different branch.
Sourcepub fn set_update_object_custom_context<T: Into<Box<UpdateObjectCustomContext>>>(
self,
v: T,
) -> Self
pub fn set_update_object_custom_context<T: Into<Box<UpdateObjectCustomContext>>>( self, v: T, ) -> Self
Sets the value of transformation
to hold a UpdateObjectCustomContext.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::UpdateObjectCustomContext;
let x = BucketOperation::new().set_update_object_custom_context(UpdateObjectCustomContext::default()/* use setters */);
assert!(x.update_object_custom_context().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.delete_object().is_none());
assert!(x.put_metadata().is_none());
assert!(x.rewrite_object().is_none());Trait Implementations
Sourceimpl Clone for BucketOperation
impl Clone for BucketOperation
Sourcefn clone(&self) -> BucketOperation
fn clone(&self) -> BucketOperation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BucketOperation
impl Debug for BucketOperation
Sourceimpl Default for BucketOperation
impl Default for BucketOperation
Sourcefn default() -> BucketOperation
fn default() -> BucketOperation
Sourceimpl Message for BucketOperation
impl Message for BucketOperation
Sourceimpl PartialEq for BucketOperation
impl PartialEq for BucketOperation
impl StructuralPartialEq for BucketOperation