Counters

Struct Counters 

#[non_exhaustive]
pub struct Counters { pub total_object_count: i64, pub succeeded_object_count: i64, pub failed_object_count: i64, pub total_bytes_found: Option<i64>, pub object_custom_contexts_created: Option<i64>, pub object_custom_contexts_deleted: Option<i64>, pub object_custom_contexts_updated: Option<i64>, /* private fields */ }
Describes details about the progress of the job.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
total_object_count: i64

Output only. Number of objects listed.

succeeded_object_count: i64

Output only. Number of objects completed.

failed_object_count: i64

Output only. The number of objects that failed due to user errors or service errors.

total_bytes_found: Option<i64>

Output only. Number of bytes found from source. This field is only populated for jobs with a prefix list object configuration.

object_custom_contexts_created: Option<i64>

Output only. Number of object custom contexts created. This field is only populated for jobs with the UpdateObjectCustomContext transformation.

object_custom_contexts_deleted: Option<i64>

Output only. Number of object custom contexts deleted. This field is only populated for jobs with the UpdateObjectCustomContext transformation.

object_custom_contexts_updated: Option<i64>

Output only. Number of object custom contexts updated. This counter tracks custom contexts where the key already existed, but the payload was modified. This field is only populated for jobs with the UpdateObjectCustomContext transformation.

Implementations

Source

impl Counters

pub fn new() -> Self

Creates a new default instance.

pub fn set_total_object_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of total_object_count.

Example
let x = Counters::new().set_total_object_count(42);
pub fn set_succeeded_object_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of succeeded_object_count.

Example
let x = Counters::new().set_succeeded_object_count(42);
pub fn set_failed_object_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of failed_object_count.

Example
let x = Counters::new().set_failed_object_count(42);
pub fn set_total_bytes_found<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of total_bytes_found.

Example
let x = Counters::new().set_total_bytes_found(42);
pub fn set_or_clear_total_bytes_found<T>(self, v: Option<T>) -> Self
where T: Into<i64>,

Sets or clears the value of total_bytes_found.

Example
let x = Counters::new().set_or_clear_total_bytes_found(Some(42));
let x = Counters::new().set_or_clear_total_bytes_found(None::<i32>);
pub fn set_object_custom_contexts_created<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of object_custom_contexts_created.

Example
let x = Counters::new().set_object_custom_contexts_created(42);
pub fn set_or_clear_object_custom_contexts_created<T>( self, v: Option<T>, ) -> Self
where T: Into<i64>,

Sets or clears the value of object_custom_contexts_created.

Example
let x = Counters::new().set_or_clear_object_custom_contexts_created(Some(42));
let x = Counters::new().set_or_clear_object_custom_contexts_created(None::<i32>);
pub fn set_object_custom_contexts_deleted<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of object_custom_contexts_deleted.

Example
let x = Counters::new().set_object_custom_contexts_deleted(42);
pub fn set_or_clear_object_custom_contexts_deleted<T>( self, v: Option<T>, ) -> Self
where T: Into<i64>,

Sets or clears the value of object_custom_contexts_deleted.

Example
let x = Counters::new().set_or_clear_object_custom_contexts_deleted(Some(42));
let x = Counters::new().set_or_clear_object_custom_contexts_deleted(None::<i32>);
pub fn set_object_custom_contexts_updated<T>(self, v: T) -> Self
where T: Into<i64>,

Sets the value of object_custom_contexts_updated.

Example
let x = Counters::new().set_object_custom_contexts_updated(42);
pub fn set_or_clear_object_custom_contexts_updated<T>( self, v: Option<T>, ) -> Self
where T: Into<i64>,

Sets or clears the value of object_custom_contexts_updated.

Example
let x = Counters::new().set_or_clear_object_custom_contexts_updated(Some(42));
let x = Counters::new().set_or_clear_object_custom_contexts_updated(None::<i32>);