#[non_exhaustive]pub struct CustomContextUpdates {
pub updates: HashMap<String, ObjectCustomContextPayload>,
pub keys_to_clear: Vec<String>,
/* private fields */
}Expand description
Describes a collection of updates to apply to custom contexts identified by key.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.updates: HashMap<String, ObjectCustomContextPayload>Optional. Insert or update the existing custom contexts.
keys_to_clear: Vec<String>Optional. Custom contexts to clear by key.
A key cannot be present in both updates and keys_to_clear.
Implementations
Sourceimpl CustomContextUpdates
impl CustomContextUpdates
pub fn new() -> Self
Sourcepub fn set_updates<T, K, V>(self, v: T) -> Self
pub fn set_updates<T, K, V>(self, v: T) -> Self
Sets the value of updates.
Example
ⓘ
use google_cloud_storagebatchoperations_v1::model::ObjectCustomContextPayload;
let x = CustomContextUpdates::new().set_updates([
("key0", ObjectCustomContextPayload::default()/* use setters */),
("key1", ObjectCustomContextPayload::default()/* use (different) setters */),
]);Sourcepub fn set_keys_to_clear<T, V>(self, v: T) -> Self
pub fn set_keys_to_clear<T, V>(self, v: T) -> Self
Sets the value of keys_to_clear.
Example
ⓘ
let x = CustomContextUpdates::new().set_keys_to_clear(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for CustomContextUpdates
impl Clone for CustomContextUpdates
Sourcefn clone(&self) -> CustomContextUpdates
fn clone(&self) -> CustomContextUpdates
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomContextUpdates
impl Debug for CustomContextUpdates
Sourceimpl Default for CustomContextUpdates
impl Default for CustomContextUpdates
Sourcefn default() -> CustomContextUpdates
fn default() -> CustomContextUpdates
Returns the “default value” for a type. Read more
Sourceimpl Message for CustomContextUpdates
impl Message for CustomContextUpdates
Sourceimpl PartialEq for CustomContextUpdates
impl PartialEq for CustomContextUpdates
impl StructuralPartialEq for CustomContextUpdates