#[non_exhaustive]pub struct DeleteJobRequest {
pub name: String,
pub request_id: String,
pub force: bool,
/* private fields */
}Expand description
Message for deleting a Job
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the job to delete.
Format: projects/{project_id}/locations/global/jobs/{job_id} .
request_id: StringOptional. An optional request ID to identify requests. Specify a unique
request ID in case you need to retry your request. Requests with same
request_id will be ignored for at least 60 minutes since the first
request. The request ID must be a valid UUID with the exception that zero
UUID is not supported (00000000-0000-0000-0000-000000000000).
force: boolOptional. If set to true, any child bucket operations of the job will also be deleted. Highly recommended to be set to true by all clients. Users cannot mutate bucket operations directly, so only the jobs.delete permission is required to delete a job (and its child bucket operations).
Implementations