#[non_exhaustive]pub struct Job {Show 13 fields
pub name: String,
pub description: String,
pub logging_config: Option<LoggingConfig>,
pub create_time: Option<Timestamp>,
pub schedule_time: Option<Timestamp>,
pub complete_time: Option<Timestamp>,
pub counters: Option<Counters>,
pub error_summaries: Vec<ErrorSummary>,
pub state: State,
pub dry_run: bool,
pub is_multi_bucket_job: bool,
pub source: Option<Source>,
pub transformation: Option<Transformation>,
/* private fields */
}Expand description
The Storage Batch Operations Job description.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the Job. job_id is unique within the project, that is either set by the customer or defined by the service. Format: projects/{project}/locations/global/jobs/{job_id} . For example: “projects/123456/locations/global/jobs/job01”.
description: StringOptional. A description provided by the user for the job. Its max length is 1024 bytes when Unicode-encoded.
logging_config: Option<LoggingConfig>Optional. Logging configuration.
create_time: Option<Timestamp>Output only. The time that the job was created.
schedule_time: Option<Timestamp>Output only. The time that the job was scheduled.
complete_time: Option<Timestamp>Output only. The time that the job was completed.
counters: Option<Counters>Output only. Information about the progress of the job.
error_summaries: Vec<ErrorSummary>Output only. Summarizes errors encountered with sample error log entries.
state: StateOutput only. State of the job.
dry_run: boolOptional. If true, the job will run in dry run mode, returning the total object count and, if the object configuration is a prefix list, the bytes found from source. No transformations will be performed.
is_multi_bucket_job: boolOutput only. If true, this Job operates on multiple buckets. Multibucket jobs are subject to different quota limits than single-bucket jobs.
source: Option<Source>Specifies objects to be transformed.
transformation: Option<Transformation>Operation to be performed on the objects.
Implementations
Sourceimpl Job
impl Job
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_logging_config<T>(self, v: T) -> Selfwhere
T: Into<LoggingConfig>,
pub fn set_logging_config<T>(self, v: T) -> Selfwhere
T: Into<LoggingConfig>,
Sets the value of logging_config.
Example
use google_cloud_storagebatchoperations_v1::model::LoggingConfig;
let x = Job::new().set_logging_config(LoggingConfig::default()/* use setters */);Sourcepub fn set_or_clear_logging_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingConfig>,
pub fn set_or_clear_logging_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LoggingConfig>,
Sets or clears the value of logging_config.
Example
use google_cloud_storagebatchoperations_v1::model::LoggingConfig;
let x = Job::new().set_or_clear_logging_config(Some(LoggingConfig::default()/* use setters */));
let x = Job::new().set_or_clear_logging_config(None::<LoggingConfig>);Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Job::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Job::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Job::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_schedule_time<T>(self, v: T) -> Self
pub fn set_schedule_time<T>(self, v: T) -> Self
Sets the value of schedule_time.
Example
use wkt::Timestamp;
let x = Job::new().set_schedule_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_schedule_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_schedule_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of schedule_time.
Example
use wkt::Timestamp;
let x = Job::new().set_or_clear_schedule_time(Some(Timestamp::default()/* use setters */));
let x = Job::new().set_or_clear_schedule_time(None::<Timestamp>);Sourcepub fn set_complete_time<T>(self, v: T) -> Self
pub fn set_complete_time<T>(self, v: T) -> Self
Sets the value of complete_time.
Example
use wkt::Timestamp;
let x = Job::new().set_complete_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_complete_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_complete_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of complete_time.
Example
use wkt::Timestamp;
let x = Job::new().set_or_clear_complete_time(Some(Timestamp::default()/* use setters */));
let x = Job::new().set_or_clear_complete_time(None::<Timestamp>);Sourcepub fn set_counters<T>(self, v: T) -> Self
pub fn set_counters<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_counters<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_counters<T>(self, v: Option<T>) -> Self
Sourcepub fn set_error_summaries<T, V>(self, v: T) -> Self
pub fn set_error_summaries<T, V>(self, v: T) -> Self
Sets the value of error_summaries.
Example
use google_cloud_storagebatchoperations_v1::model::ErrorSummary;
let x = Job::new()
.set_error_summaries([
ErrorSummary::default()/* use setters */,
ErrorSummary::default()/* use (different) setters */,
]);Sourcepub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self
pub fn set_dry_run<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_is_multi_bucket_job<T: Into<bool>>(self, v: T) -> Self
pub fn set_is_multi_bucket_job<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::BucketList;
let x = Job::new().set_source(Some(
google_cloud_storagebatchoperations_v1::model::job::Source::BucketList(BucketList::default().into())));Sourcepub fn bucket_list(&self) -> Option<&Box<BucketList>>
pub fn bucket_list(&self) -> Option<&Box<BucketList>>
The value of source
if it holds a BucketList, None if the field is not set or
holds a different branch.
Sourcepub fn set_bucket_list<T: Into<Box<BucketList>>>(self, v: T) -> Self
pub fn set_bucket_list<T: Into<Box<BucketList>>>(self, v: T) -> Self
Sourcepub fn set_transformation<T: Into<Option<Transformation>>>(self, v: T) -> Self
pub fn set_transformation<T: Into<Option<Transformation>>>(self, v: T) -> Self
Sets the value of transformation.
Note that all the setters affecting transformation are mutually
exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PutObjectHold;
let x = Job::new().set_transformation(Some(
google_cloud_storagebatchoperations_v1::model::job::Transformation::PutObjectHold(PutObjectHold::default().into())));Sourcepub fn put_object_hold(&self) -> Option<&Box<PutObjectHold>>
pub fn put_object_hold(&self) -> Option<&Box<PutObjectHold>>
The value of transformation
if it holds a PutObjectHold, None if the field is not set or
holds a different branch.
Sourcepub fn set_put_object_hold<T: Into<Box<PutObjectHold>>>(self, v: T) -> Self
pub fn set_put_object_hold<T: Into<Box<PutObjectHold>>>(self, v: T) -> Self
Sets the value of transformation
to hold a PutObjectHold.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PutObjectHold;
let x = Job::new().set_put_object_hold(PutObjectHold::default()/* use setters */);
assert!(x.put_object_hold().is_some());
assert!(x.delete_object().is_none());
assert!(x.put_metadata().is_none());
assert!(x.rewrite_object().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn delete_object(&self) -> Option<&Box<DeleteObject>>
pub fn delete_object(&self) -> Option<&Box<DeleteObject>>
The value of transformation
if it holds a DeleteObject, None if the field is not set or
holds a different branch.
Sourcepub fn set_delete_object<T: Into<Box<DeleteObject>>>(self, v: T) -> Self
pub fn set_delete_object<T: Into<Box<DeleteObject>>>(self, v: T) -> Self
Sets the value of transformation
to hold a DeleteObject.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::DeleteObject;
let x = Job::new().set_delete_object(DeleteObject::default()/* use setters */);
assert!(x.delete_object().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.put_metadata().is_none());
assert!(x.rewrite_object().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn put_metadata(&self) -> Option<&Box<PutMetadata>>
pub fn put_metadata(&self) -> Option<&Box<PutMetadata>>
The value of transformation
if it holds a PutMetadata, None if the field is not set or
holds a different branch.
Sourcepub fn set_put_metadata<T: Into<Box<PutMetadata>>>(self, v: T) -> Self
pub fn set_put_metadata<T: Into<Box<PutMetadata>>>(self, v: T) -> Self
Sets the value of transformation
to hold a PutMetadata.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::PutMetadata;
let x = Job::new().set_put_metadata(PutMetadata::default()/* use setters */);
assert!(x.put_metadata().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.delete_object().is_none());
assert!(x.rewrite_object().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn rewrite_object(&self) -> Option<&Box<RewriteObject>>
pub fn rewrite_object(&self) -> Option<&Box<RewriteObject>>
The value of transformation
if it holds a RewriteObject, None if the field is not set or
holds a different branch.
Sourcepub fn set_rewrite_object<T: Into<Box<RewriteObject>>>(self, v: T) -> Self
pub fn set_rewrite_object<T: Into<Box<RewriteObject>>>(self, v: T) -> Self
Sets the value of transformation
to hold a RewriteObject.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::RewriteObject;
let x = Job::new().set_rewrite_object(RewriteObject::default()/* use setters */);
assert!(x.rewrite_object().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.delete_object().is_none());
assert!(x.put_metadata().is_none());
assert!(x.update_object_custom_context().is_none());Sourcepub fn update_object_custom_context(
&self,
) -> Option<&Box<UpdateObjectCustomContext>>
pub fn update_object_custom_context( &self, ) -> Option<&Box<UpdateObjectCustomContext>>
The value of transformation
if it holds a UpdateObjectCustomContext, None if the field is not set or
holds a different branch.
Sourcepub fn set_update_object_custom_context<T: Into<Box<UpdateObjectCustomContext>>>(
self,
v: T,
) -> Self
pub fn set_update_object_custom_context<T: Into<Box<UpdateObjectCustomContext>>>( self, v: T, ) -> Self
Sets the value of transformation
to hold a UpdateObjectCustomContext.
Note that all the setters affecting transformation are
mutually exclusive.
Example
use google_cloud_storagebatchoperations_v1::model::UpdateObjectCustomContext;
let x = Job::new().set_update_object_custom_context(UpdateObjectCustomContext::default()/* use setters */);
assert!(x.update_object_custom_context().is_some());
assert!(x.put_object_hold().is_none());
assert!(x.delete_object().is_none());
assert!(x.put_metadata().is_none());
assert!(x.rewrite_object().is_none());Trait Implementations
impl StructuralPartialEq for Job