ObjectCustomContextPayload

Struct ObjectCustomContextPayload 

#[non_exhaustive]
pub struct ObjectCustomContextPayload { pub value: Option<String>, /* private fields */ }
Describes the payload of a user defined object custom context.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
value: Option<String>

The value of the object custom context. If set, value must NOT be an empty string since it is a required field in custom context. If unset, value will be ignored and no changes will be made to the value field of the custom context payload.

Implementations

Source

impl ObjectCustomContextPayload

pub fn new() -> Self

pub fn set_value<T>(self, v: T) -> Self
where T: Into<String>,

Sets the value of value.

Example
let x = ObjectCustomContextPayload::new().set_value("example");
pub fn set_or_clear_value<T>(self, v: Option<T>) -> Self
where T: Into<String>,

Sets or clears the value of value.

Example
let x = ObjectCustomContextPayload::new().set_or_clear_value(Some("example"));
let x = ObjectCustomContextPayload::new().set_or_clear_value(None::<String>);