#[non_exhaustive]pub struct UpdateObjectCustomContext {
pub action: Option<Action>,
/* private fields */
}Expand description
Describes options to update object custom contexts.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: Option<Action>One of the actions must be set.
Implementations
Sourceimpl UpdateObjectCustomContext
impl UpdateObjectCustomContext
pub fn new() -> Self
Sourcepub fn set_action<T: Into<Option<Action>>>(self, v: T) -> Self
pub fn set_action<T: Into<Option<Action>>>(self, v: T) -> Self
Sourcepub fn custom_context_updates(&self) -> Option<&Box<CustomContextUpdates>>
pub fn custom_context_updates(&self) -> Option<&Box<CustomContextUpdates>>
The value of action
if it holds a CustomContextUpdates, None if the field is not set or
holds a different branch.
Sourcepub fn set_custom_context_updates<T: Into<Box<CustomContextUpdates>>>(
self,
v: T,
) -> Self
pub fn set_custom_context_updates<T: Into<Box<CustomContextUpdates>>>( self, v: T, ) -> Self
Sets the value of action
to hold a CustomContextUpdates.
Note that all the setters affecting action are
mutually exclusive.
Example
ⓘ
use google_cloud_storagebatchoperations_v1::model::CustomContextUpdates;
let x = UpdateObjectCustomContext::new().set_custom_context_updates(CustomContextUpdates::default()/* use setters */);
assert!(x.custom_context_updates().is_some());
assert!(x.clear_all().is_none());Sourcepub fn clear_all(&self) -> Option<&bool>
pub fn clear_all(&self) -> Option<&bool>
The value of action
if it holds a ClearAll, None if the field is not set or
holds a different branch.
Sourcepub fn set_clear_all<T: Into<bool>>(self, v: T) -> Self
pub fn set_clear_all<T: Into<bool>>(self, v: T) -> Self