The messages and enums that are part of this client library.
Modules
- bucket_
list - Defines additional types related to BucketList.
- bucket_
operation - Defines additional types related to BucketOperation.
- job
- Defines additional types related to Job.
- logging_
config - Defines additional types related to LoggingConfig.
- object_
retention - Defines additional types related to ObjectRetention.
- put_
object_ hold - Defines additional types related to PutObjectHold.
- update_
object_ custom_ context - Defines additional types related to UpdateObjectCustomContext.
Structs
- Bucket
List - Describes list of buckets and their objects to be transformed.
- Bucket
Operation - BucketOperation represents a bucket-level breakdown of a Job.
- Cancel
JobRequest - Message for Job to Cancel
- Cancel
JobResponse - Message for response to cancel Job.
- Counters
- Describes details about the progress of the job.
- Create
JobRequest - Message for creating a Job
- Custom
Context Updates - Describes a collection of updates to apply to custom contexts identified by key.
- Delete
JobRequest - Message for deleting a Job
- Delete
Object - Describes options to delete an object.
- Error
LogEntry - An entry describing an error that has occurred.
- Error
Summary - A summary of errors by error code, plus a count and sample error log entries.
- GetBucket
Operation Request - Message for getting a BucketOperation.
- GetJob
Request - Message for getting a Job
- Job
- The Storage Batch Operations Job description.
- List
Bucket Operations Request - Message for request to list BucketOperations
- List
Bucket Operations Response - Message for response to listing BucketOperations
- List
Jobs Request - Message for request to list Jobs
- List
Jobs Response - Message for response to listing Jobs
- Logging
Config - Specifies the Cloud Logging behavior.
- Manifest
- Describes list of objects to be transformed.
- Object
Custom Context Payload - Describes the payload of a user defined object custom context.
- Object
Retention - Describes options for object retention update.
- Operation
Metadata - Represents the metadata of the long-running operation.
- Prefix
List - Describes prefixes of objects to be transformed.
- PutMetadata
- Describes options for object metadata update.
- PutObject
Hold - Describes options to update object hold.
- Rewrite
Object - Describes options for object rewrite.
- Update
Object Custom Context - Describes options to update object custom contexts.