#[non_exhaustive]pub struct ObjectCustomContextPayload {
pub value: Option<String>,
/* private fields */
}Expand description
Describes the payload of a user defined object custom context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: Option<String>The value of the object custom context.
If set, value must NOT be an empty string since it is a required field in
custom context. If unset, value will be ignored and no changes will be
made to the value field of the custom context payload.
Implementations